.style_container_VCsHx {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1000;
}
.style_loader_CNsNi {
  display: block;
  position: relative;
  left: 50%;
  top: calc(50% - 50px);
  width: 150px;
  height: 150px;
  margin: -75px 0 0 -75px;
  border-radius: 50%;
  border: 10px solid transparent;
  border-top-color: #ac262c; /* Chrome, Opera 15+, Safari 5+ */
  animation: style_spin_BAaPb 2s linear infinite; /* Chrome, Firefox 16+, IE 10+, Opera */
}
.style_loader_CNsNi:before {
  content: '';
  position: absolute;
  top: 5px;
  left: 5px;
  right: 5px;
  bottom: 5px;
  border-radius: 50%;
  border: 10px solid transparent;
  border-top-color: #258e44; /* Chrome, Opera 15+, Safari 5+ */
  animation: style_spin_BAaPb 3s linear infinite; /* Chrome, Firefox 16+, IE 10+, Opera */
}
.style_loader_CNsNi:after {
  content: '';
  position: absolute;
  top: 20px;
  left: 20px;
  right: 20px;
  bottom: 20px;
  border-radius: 50%;
  border: 10px solid transparent;
  border-top-color: #1c4678; /* Chrome, Opera 15+, Safari 5+ */
  animation: style_spin_BAaPb 1.5s linear infinite; /* Chrome, Firefox 16+, IE 10+, Opera */
}
.style_message_rmggO {
  position: absolute;
  text-align: center;
  width: 100%;
  top: calc(50% + 50px);
  font-size: 200%;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;
}
@keyframes style_spin_BAaPb {
0% { /* Chrome, Opera 15+, Safari 3.1+ */ /* IE 9 */
    transform: rotate(0deg); /* Firefox 16+, IE 10+, Opera */
}
100% { /* Chrome, Opera 15+, Safari 3.1+ */ /* IE 9 */
    transform: rotate(360deg); /* Firefox 16+, IE 10+, Opera */
}
}

.style_container_n4xKQ {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1000;
}
.style_center_xzh58 {
  position: relative;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
  -ms-transform: translate(-50%, -50%);
  width: 80%;
  text-align: center;
}
.style_button_kGhdk {
  display: flex;
  justify-content: space-around;
  text-align: center;
  -webkit-user-select: none;
     -moz-user-select: none;
      -ms-user-select: none;
          user-select: none;

  background-color: #f1f1f1;
  color: black;
  font-size: 16px;
  padding: 10px 20px;
  border: none;
  cursor: pointer;
  border-radius: 5px;
  text-align: center;
  width: 200px;
  margin: 10px auto;
}

